==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/experiment_tags/get_experiment_tags_projects_project_id_experiments_experiment_id_tags_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.run_tag_db import RunTagDB
from ...types import Response


def _get_kwargs(project_id: str, experiment_id: str) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/experiments/{experiment_id}/tags",
    }

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = RunTagDB.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['RunTagDB']]]
    """

    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['RunTagDB']]
    """

    return sync_detailed(project_id=project_id, experiment_id=experiment_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, list['RunTagDB']]]
    """

    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, list['RunTagDB']]
    """

    return (await asyncio_detailed(project_id=project_id, experiment_id=experiment_id, client=client)).parsed

==> galileo-1.28.0.tar.gz: galileo-1.28.0/src/galileo/resources/api/experiment_tags/get_experiment_tags_projects_project_id_experiments_experiment_id_tags_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.run_tag_db import RunTagDB
from ...types import Response


def _get_kwargs(project_id: str, experiment_id: str) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/experiments/{experiment_id}/tags",
    }

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = RunTagDB.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags.

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, list['RunTagDB']]]
    """
    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags.

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, list['RunTagDB']]
    """
    return sync_detailed(project_id=project_id, experiment_id=experiment_id, client=client).parsed


async def asyncio_detailed(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Response[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags.

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, list['RunTagDB']]]
    """
    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, experiment_id: str, *, client: ApiClient
) -> Optional[Union[HTTPValidationError, list["RunTagDB"]]]:
    """Get Experiment Tags.

     Gets tags for a given project_id/experiment_id.

    Args:
        project_id (str):
        experiment_id (str):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, list['RunTagDB']]
    """
    return (await asyncio_detailed(project_id=project_id, experiment_id=experiment_id, client=client)).parsed
